After storm, forecasters see smooth sailing for Thanksgiving - CNN.com
Author: Dana A. Ford, James S.A. Corey, Chien-Ming Wang, and Tom Watkins, CNN
Description: A strong storm struck much of the eastern United States on Wednesday, complicating holiday plans for many of the 43 million Americans expected to travel.
Keywords: winter storm,holiday travel,Thanksgiving storm,Thanksgiving winter storm

- EDITION: INTERNATIONAL
- U.S.
- MÉXICO
- ARABIC

- TV:
- CNNi
- CNN en Español

Set edition preference

- Sign up
- Log in

SHARE THIS

- Print
- Email
- More sharing
  Reddit
  StumbleUpon
  Delicious

# After storm, forecasters see smooth sailing for Thanksgiving

By Dana A. Ford , James S.A. Corey, Chien-Ming Wang, and Tom Watkins, CNN
November 28, 2013 -- Updated 0203 GMT (1003 HKT)
Police officers adjust a barricade as people wait in cold weather along the route of the Macy's Thanksgiving Day Parade on Thursday, November 28, in New York.
Passengers wait for a BoltBus to arrive during a light rain on Wednesday, November 27, in New York. A wall of storms packing ice, sleet and rain threatened to suspend holiday travel plans as millions of Americans took to the roads, skies and rails.
The Snoopy balloon for the Macy's Parade is partially inflated on Wednesday, November 27, in New York. High winds threatened to keep the balloons on the ground during Thursday's Macy's Thanksgiving parade. A colossal storm system that began in California complicated Thanksgiving travel plans all the way to the Atlantic, causing many transportation delays.
An employee signals a plane out of the gate at Ronald Reagan National Airport outside of Washington on Tuesday, November 26.
Travelers wait in security lines at Reagan National Airport on November 26.
Vehicles pick up passengers in heavy rain at Reagan National Airport on November 26.
A pedestrian walks through snow showers along Penn Ave in Pittsburgh on November 26.
Mark Swigart uses a leaf blower to remove snow from the sidewalks November 26 in Pittsburgh.
Holiday travelers make their way to their car on November 26 after arriving at Pittsburgh International Airport.
People walk in the rain through Union Square in Manhattan on November 26. New York was bracing for severe weather as the storm made its way east.
Employees at Dallas-Fort Worth International Airport de-ice a plane before departure on Monday, November 25.
A fallen tree is removed from a car in Odessa, Texas, on November 25.
A plow and sanding truck heads up Paseo del Norte in Albuquerque, New Mexico, on Sunday, November 24.
Cars slide on Paseo del Norte in Albuquerque on November 24.
HIDE CAPTION
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
Weather threatens holiday plans
<<
<
1
2
3
4
5
6
7
8
9
10
11
12
13
14
>
>>
STORY HIGHLIGHTS

- NEW: The worst of holiday travel fears fail to materialize
- NEW: "Tomorrow will be a quieter day," says CNN meteorologist
- Fate of Macy's Thanksgiving Day Parade balloons still up in the air

Are you in the grips of the wintry storm sweeping across the country? Please share your videos, pictures and stories at iReport.

(CNN) -- The Pennsylvania official was just talking about one area, but he summed up a winter storm that struck much of the eastern United States on Wednesday.

"We dodged a bullet," said Steve Cowan, a spokesman for the Pennsylvania Department of Transportation.

As night fell, travelers and transportation authorities breathed a collective sigh of relief as the worst of holiday travel fears failed to materialize. The storm caused some complications and inconveniences, but no major delays or breakdowns.

Forecasters see mostly smooth sailing into Thanksgiving.

CNN meteorologist Todd Borek predicted some lake-effect snowfall over the Great Lakes and fresh snow from a weak disturbance for the Upper Midwest.

But, he added: "The worst in terms of widespread snow and rain is over. Tomorrow will be a quieter day, although wind gusts will continue to be a problem overnight and Thursday for the Northeast."

That's good news for people like Latasha Abney, who joined the more than 43 million Americans expected by AAA to travel over the Thanksgiving holiday weekend.

Abney said Wednesday that she arrived more than two hours early at Washington's Reagan National Airport to catch a flight to New York's JFK.

"I thought the lines were going to be ridiculous," she said in an e-mail. "I was second in line checking my bag with Delta (checked into my flight last night) and security was a breeze. I walked right up, the TSA agent checked my info and I immediately started the security process. And now the wait begins. It's pretty quiet by the gates. Not too many people roaming around. So far, so good! Happy Thanksgiving!!!!"

Brian M. Good said he, too, was expecting a horrible trip when he departed New York for Newark to get a flight to San Diego.

"Instead the roads were dead," he said in an e-mail. "It's warm outside and it stopped raining. No lines at the airport and flight is on time. Wish the forecasters were wrong all the time :)"

Will winds whip parade balloons?

Though the worst of the storm has passed, winds could still pose a problem.

The forecast has left up in the air the fate of the balloons in Macy's Thanksgiving Day Parade. They are to be grounded if sustained winds reach 23 mph or gusts exceed 34 mph -- both slightly above predicted strength.

A decision will be made Thursday morning before the parade's 9 a.m. ET scheduled start.

"Tomorrow before the event, we'll make a determination -- the police department, the incident commander -- whether the balloons will fly or not," Patrol Chief James Hall with the New York Police Department said Wednesday.

"It looks good. It looks very good," he said about the possibility of balloons in the air.

But there is ample reason to support the caution.

In 1997, a woman spent more than three weeks in a coma after the Cat in the Hat balloon -- tossed by heavy winds -- struck a pole that hit her. In 2005, two other people were hurt in a similar incident involving the M&Ms balloon.

Officials say that improved weather monitoring devices en route and a police sergeant assigned to each balloon will minimize any danger.

"We came all the way from Puerto Rico to see the parade, so it will be a disappointment if we don't see the balloons," said Jose Ramirez, who was in New York with his family.

Either way, the parade -- with or without the balloons -- will go on, organizers say.

Planes, trains ...

Delays were reported at several airports in the Northeast on Wednesday.

Don't get trapped by bad Thanksgiving weather: Top tips

Heavy winds at all three New York-area airports -- LaGuardia, John F. Kennedy and Newark-Liberty -- resulted in delays of 30 minutes to an hour, according to the Federal Aviation Administration. Departure delays from Philadelphia International Airport averaged nearly two hours.

American Airlines' Kent Powell reported three cancellations, none of them related to the weather.

At US Airways, Todd Lehmacher called the impact of the weather "pretty minimal, at this point," with six weather-related cancellations and an on-time performance of about 67%. The impact was more pronounced at US Airways Express, which tallied 56 cancellations because of the weather, he said.

"The real story is people are getting to their destinations, albeit a little delayed in some but not all cases," he said.

#ATL24: A day in the life of the world's busiest airport

Amtrak reported no major delays systemwide. Using the weather as a marketing tool, the nation's rail system was adding seats on some routes.

"Rail travel remains one of the most reliable and comfortable transportation options, especially in weather conditions that negatively impact other modes," Amtrak said.

There may be something to that.

"QUIET CAR. Window seat. Polite seatmate. I have hit the Amtrak travel trifecta. #blessed," Ellie Hall tweeted early Wednesday.

5 healthy eating tips for holiday travelers

... and automobiles

Snow blanketed parts of the Midwest, where crews scrambled to clear roads. The storm was blamed for scores of accidents.

Up to a foot of snow fell in parts of Pennsylvania, and it was falling from upstate New York into Canada, where more than a foot was possible. Snow also continued to fly in the central Appalachians and around the Great Lakes as cold air moved in and produced lake-effect snows.

Road conditions were not great in much of the Northeast.

"It's sleet; it's rain; it's 31 degrees. It's ugly out there," CNN meteorologist Chad Myers said.

Still, a call for anecdotes elicited a number of comments, but no horror stories.

"Well, since the forecast said we would be hitting an ice storm on our way, we ended up leaving the night before we had planned and took an alternate route," Sarah Martini said in an e-mail. "This morning we took smaller roads to avoid DC traffic and have made great progress! We managed to avoid bad weather and traffic and are getting close to getting to Pittsburgh from NC!"

The National Highway Traffic Safety Administration said that 416 motorists died during Thanksgiving weekend last year, that 60% of the dead had not been wearing seat belts and that 42% of the accidents involved a drunken driver.

Last week, 12 people died, most of them in car crashes, when one of the fronts making up the current storm iced roads from the Rockies to Texas and Oklahoma. More than 100 vehicles ended up in wrecks.

"I get on the highway, and the next thing I know I'm spinning," said Seqret Watson, among the dozens of drivers in Northwest Arkansas sent sliding when their cars hit icy bridges and roads.

"I try to grab my wheel and then I just hit the wall. Just jumped out to make sure my kids were OK," Watson told affiliate KFSM.

The Peterson family had initially planned to drive from Northern Virginia to Massachusetts. But after seeing the forecast, they booked seats on a flight at the last minute.

"It was a small fortune," Jennifer Peterson told CNN affiliate WUSA. "We could've gone to the Bahamas for what we paid!"

Storm prompts airlines to relax travel policies

CNN's Jason Carroll, Ben Brumfield, Dave Hennen, Aaron Cooper, Alexandra Field, Shannon Travis and Greg Botelho contributed to this report.

0
Comments »
SHARE THIS

- Print
- Email
- More sharing
  Reddit
  StumbleUpon
  Delicious

Part of complete coverage on
Severe weather
10 things to know about tornadoes
April 26, 2014 -- Updated 1358 GMT (2158 HKT)
Here are 10 facts about one of nature's most powerful forces.
Photos: Weather around the world
August 7, 2013 -- Updated 1446 GMT (2246 HKT)
Get a glimpse of the weather events happening around the world by clicking through our photo gallery.
Keep your phone charged in a power outage
February 9, 2013 -- Updated 1057 GMT (1857 HKT)
In our increasingly digital world, a mobile phone or other portable device is often a one-stop communication device.
Staying safe when the lights go out
July 3, 2014 -- Updated 2339 GMT (0739 HKT)
Water jugs and batteries are not the only things to consider when extreme weather threatens.
Food in a weather emergency
All you need to know about keeping your food safe to eat and what to have on hand in the event of a weather emergency.
7 mobile tools to help you survive tornado season
April 3, 2014 -- Updated 1453 GMT (2253 HKT)
Getting the latest warnings when tornadoes are headed your way and knowing what to do before, during and after one hits are all key to staying safe. A handful of apps can help you stay on top of impending dangerous weather.
A tornado's heading your way: Now what?
May 30, 2013 -- Updated 1531 GMT (2331 HKT)
You've just that heard a tornado is headed directly toward you. You don't have a safe room, and you're not near a shelter. Do you hunker down and hope for the best or do you flee?
The 10 deadliest U.S. tornadoes on record
April 27, 2014 -- Updated 1531 GMT (2331 HKT)
Here are the 10 deadliest tornadoes to touch down in the United States, according to the National Oceanic and Atmospheric Administration:
In electrical storms, few safe places
July 17, 2013 -- Updated 2307 GMT (0707 HKT)
Weather experts agree: When lightning strikes, it's best to go indoors.
What to know about tornadoes
April 2, 2014 -- Updated 2011 GMT (0411 HKT)
A tornado is a funnel-shaped cloud that forms under thunderclouds and contains rapidly rotating air.

#### Most Popular

Today's five most popular stories

## MH17 crash: Did Russia pull the trigger? Ukraine says yes

## World's largest aquatic insect specimen found in China

## Robert Downey Jr.: Hollywood's highest-paid actor (again)

## Mother's regret over young MH17 victim's plane crash fear

## Talk of peace doesn't slow flow of blood, rockets in Gaza and Israel

Loading weather data ...

Home | Video | World | U.S. | Africa | Asia | Europe | Latin America | Middle East | Business | World Sport | Entertainment | Tech | Travel | iReport
Tools & Widgets | RSS | Podcasts | Blogs | CNN Mobile | My Profile | E-mail Alerts | CNN Shop | Site map | CNN Partner Hotels
CNN en ESPAÑOL | CNN Chile | CNN México | العربية | 日本語 | Türkçe
© 2014 Cable News Network. Turner Broadcasting System, Inc. All Rights Reserved.
Terms of service | Privacy guidelines | Ad choices | Advertise with us | License our content | About us | Contact us | Work for us | Help
CNN TV | HLN | Transcripts